summaryrefslogtreecommitdiffstats
path: root/konq-plugins/domtreeviewer/domtreecommands.h
diff options
context:
space:
mode:
Diffstat (limited to 'konq-plugins/domtreeviewer/domtreecommands.h')
-rw-r--r--konq-plugins/domtreeviewer/domtreecommands.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/konq-plugins/domtreeviewer/domtreecommands.h b/konq-plugins/domtreeviewer/domtreecommands.h
index f068426..43af96b 100644
--- a/konq-plugins/domtreeviewer/domtreecommands.h
+++ b/konq-plugins/domtreeviewer/domtreecommands.h
@@ -51,9 +51,10 @@ TQString domErrorMessage(int exception_code);
* Internal class for emitting signals.
* @internal
*/
-class ManipulationCommandSignalEmitter : public QObject
+class ManipulationCommandSignalEmitter : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
ManipulationCommandSignalEmitter();
virtual ~ManipulationCommandSignalEmitter();
@@ -73,7 +74,7 @@ signals:
*/
void error(int err_id, const TQString &msg);
-private: // make moc not complain
+private: // make tqmoc not complain
friend class ManipulationCommand;
};
@@ -276,10 +277,10 @@ class ManipulateNodeCommand : public ManipulationCommand
{
public:
/**
* Prepare command, where \c node is to be contained in \c parent, just
* before \c after. If \c after is 0, it is appended at the end.
*/
- ManipulateNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
+ ManipulateNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
virtual ~ManipulateNodeCommand();
protected:
@@ -303,10 +304,10 @@ class InsertNodeCommand : public ManipulateNodeCommand
{
public:
/**
* Prepare insertion command, inserting \c node into \c parent, just
* before \c after. If \c after is 0, append it to the list of children.
*/
- InsertNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
+ InsertNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
virtual ~InsertNodeCommand();
virtual TQString name() const;
@@ -329,10 +330,10 @@ class RemoveNodeCommand : public ManipulateNodeCommand
{
public:
/**
* Prepare insertion command, inserting \c node into \c parent, just
* before \c after. If \c after is 0, append it to the list of children.
*/
- RemoveNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
+ RemoveNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
virtual ~RemoveNodeCommand();
virtual TQString name() const;
@@ -352,10 +353,10 @@ class MoveNodeCommand : public ManipulationCommand
{
public:
/**
* Move \c node from current position into \c parent, just before \c after.
* Appends if \c after is 0.
*/
- MoveNodeCommand(const DOM::Node &node, const DOM::Node &parent, const DOM::Node &after);
+ MoveNodeCommand(const DOM::Node &node, const DOM::Node &tqparent, const DOM::Node &after);
virtual ~MoveNodeCommand();
virtual TQString name() const;
@@ -276,10 +277,10 @@ class ManipulateNodeCommand : public ManipulationCommand
public:
/**
- * Prepare command, where \c node is to be contained in \c parent, just
+ * Prepare command, where \c node is to be contained in \c tqparent, just
* before \c after. If \c after is 0, it is appended at the end.
*/
@@ -303,10 +304,10 @@ class InsertNodeCommand : public ManipulateNodeCommand
public:
/**
- * Prepare insertion command, inserting \c node into \c parent, just
- * before \c after. If \c after is 0, append it to the list of children.
+ * Prepare insertion command, inserting \c node into \c tqparent, just
+ * before \c after. If \c after is 0, append it to the list of tqchildren.
*/
@@ -329,10 +330,10 @@ class RemoveNodeCommand : public ManipulateNodeCommand
public:
/**
- * Prepare insertion command, inserting \c node into \c parent, just
- * before \c after. If \c after is 0, append it to the list of children.
+ * Prepare insertion command, inserting \c node into \c tqparent, just
+ * before \c after. If \c after is 0, append it to the list of tqchildren.
*/
@@ -352,10 +353,10 @@ class MoveNodeCommand : public ManipulationCommand
public:
/**
- * Move \c node from current position into \c parent, just before \c after.
+ * Move \c node from current position into \c tqparent, just before \c after.
* Appends if \c after is 0.
*/